@@ -73,13 +73,25 @@ describe('bodyParser()', function () {
       })
     })
 
+    function getMajorVersion (versionString) {
+      return versionString.split('.')[0]
+    }
+
+    function shouldSkipQuery (versionString) {
+      // Skipping HTTP QUERY tests on Node 21, it is reported in http.METHODS on 21.7.2 but not supported
+      // update this implementation to run on supported versions of 21 once they exist
+      // upstream tracking https://github.com/nodejs/node/issues/51562
+      // express tracking issue: https://github.com/expressjs/express/issues/5615
+      return getMajorVersion(versionString) === '21'
+    }
+
     methods.slice().sort().forEach(function (method) {
-      if (method === 'connect') {
-        // except CONNECT
-        return
-      }
+      if (method === 'connect') return
 
       it('should support ' + method.toUpperCase() + ' requests', function (done) {
+        if (method === 'query' && shouldSkipQuery(process.versions.node)) {
+          this.skip()
+        }
         request(this.server)[method]('/')
           .set('Content-Type', 'application/json')
           .set('Content-Length', '15')
@@ -124,7 +136,7 @@ describe('bodyParser()', function () {
         .post('/')
         .set('Content-Type', 'application/json')
         .send(' {"user":"tobi"}')
-        .expect(403, 'no leading space', done)
+        .expect(403, '[entity.verify.failed] no leading space', done)
     })
 
     it('should apply to urlencoded', function (done) {
@@ -138,7 +150,7 @@ describe('bodyParser()', function () {
         .post('/')
         .set('Content-Type', 'application/x-www-form-urlencoded')
         .send(' user=tobi')
-        .expect(403, 'no leading space', done)
+        .expect(403, '[entity.verify.failed] no leading space', done)
     })
   })
 })
@@ -149,7 +161,7 @@ function createServer (opts) {
   return http.createServer(function (req, res) {
     _bodyParser(req, res, function (err) {
       res.statusCode = err ? (err.status || 500) : 200
-      res.end(err ? err.message : JSON.stringify(req.body))
+      res.end(err ? ('[' + err.type + '] ' + err.message) : JSON.stringify(req.body))
     })
   })
 }
